@@ -1,5 +1,5 @@
 import requests
-from allauth.socialaccount.app_settings import app_settings
+from allauth.socialaccount import app_settings
 from allauth.socialaccount.providers.oauth2.views import (
     OAuth2Adapter,
     OAuth2CallbackView,
